@@ -307,7 +307,9 @@ pub fn register_commands(commands: &mut CommandManager) {
 
     r("map-normal", &[], |ctx, io| map(ctx, io, ModeKind::Normal));
     r("map-insert", &[], |ctx, io| map(ctx, io, ModeKind::Insert));
-    r("map-command", &[], |ctx, io| map(ctx, io, ModeKind::Command));
+    r("map-command", &[], |ctx, io| {
+        map(ctx, io, ModeKind::Command)
+    });
     r("map-readline", &[], |ctx, io| {
         map(ctx, io, ModeKind::ReadLine)
     });
