@@ -89,7 +89,7 @@ impl Kqueue {
     pub fn new() -> Self {
         let fd = unsafe { libc::kqueue() };
         if fd == -1 {
-            panic!("could not create kqueue");
+            panic!("could not create kqueue, errno: {}", errno());
         }
         Self(fd)
     }
@@ -97,14 +97,14 @@ impl Kqueue {
     pub fn add(&self, event: Event, index: usize) {
         let event = event.into_kevent(libc::EV_ADD, index);
         if !modify_kqueue(self.0, &event) {
-            panic!("could not add event");
+            panic!("could not add event, errno: {}", errno());
         }
     }
 
     pub fn remove(&self, event: Event) {
         let event = event.into_kevent(libc::EV_DELETE, 0);
         if !modify_kqueue(self.0, &event) {
-            panic!("could not remove event");
+            panic!("could not remove event, errno: {}", errno());
         }
     }
 
@@ -140,7 +140,7 @@ impl Kqueue {
             if errno() == libc::EINTR {
                 len = 0;
             } else {
-                panic!("could not wait for events");
+                panic!("could not wait for events, errno: {}", errno());
             }
         }
 
@@ -205,6 +205,8 @@ fn run_server(config: ApplicationConfig, listener: UnixListener) {
                 }
                 None => unreachable!(),
             }
+        } else {
+            timeout = Some(Duration::ZERO);
         }
 
         for event in kqueue_events {
@@ -273,90 +275,72 @@ fn run_server(config: ApplicationConfig, listener: UnixListener) {
                 }
                 _ => unreachable!(),
             }
+        }
 
-            application.update(events.drain(..));
-            let mut requests = application.ctx.platform.requests.drain();
-            while let Some(request) = requests.next() {
-                match request {
-                    PlatformRequest::Quit => {
-                        for request in requests {
-                            if let PlatformRequest::WriteToClient { buf, .. }
-                            | PlatformRequest::WriteToProcess { buf, .. } = request
-                            {
-                                application.ctx.platform.buf_pool.release(buf);
-                            }
+        application.update(events.drain(..));
+        let mut requests = application.ctx.platform.requests.drain();
+        while let Some(request) = requests.next() {
+            match request {
+                PlatformRequest::Quit => {
+                    for request in requests {
+                        if let PlatformRequest::WriteToClient { buf, .. }
+                        | PlatformRequest::WriteToProcess { buf, .. } = request
+                        {
+                            application.ctx.platform.buf_pool.release(buf);
                         }
-                        return;
                     }
-                    PlatformRequest::Redraw => timeout = Some(Duration::ZERO),
-                    PlatformRequest::WriteToClient { handle, buf } => {
-                        let index = handle.into_index();
-                        if let Some(ref mut connection) = client_connections[index] {
-                            if connection.write_all(buf.as_bytes()).is_err() {
-                                kqueue.remove(Event::Fd(connection.as_raw_fd()));
-                                client_connections[index] = None;
-                                events.push(PlatformEvent::ConnectionClose { handle });
-                            }
-                        }
-                        application.ctx.platform.buf_pool.release(buf);
-                    }
-                    PlatformRequest::CloseClient { handle } => {
-                        let index = handle.into_index();
-                        if let Some(connection) = client_connections[index].take() {
+                    return;
+                }
+                PlatformRequest::Redraw => timeout = Some(Duration::ZERO),
+                PlatformRequest::WriteToClient { handle, buf } => {
+                    let index = handle.into_index();
+                    if let Some(ref mut connection) = client_connections[index] {
+                        if connection.write_all(buf.as_bytes()).is_err() {
                             kqueue.remove(Event::Fd(connection.as_raw_fd()));
+                            client_connections[index] = None;
+                            events.push(PlatformEvent::ConnectionClose { handle });
                         }
-                        events.push(PlatformEvent::ConnectionClose { handle });
                     }
-                    PlatformRequest::SpawnProcess {
-                        tag,
-                        mut command,
-                        buf_len,
-                    } => {
-                        let mut spawned = false;
-                        for (i, p) in processes.iter_mut().enumerate() {
-                            if p.is_some() {
-                                continue;
-                            }
+                    application.ctx.platform.buf_pool.release(buf);
+                }
+                PlatformRequest::CloseClient { handle } => {
+                    let index = handle.into_index();
+                    if let Some(connection) = client_connections[index].take() {
+                        kqueue.remove(Event::Fd(connection.as_raw_fd()));
+                    }
+                    events.push(PlatformEvent::ConnectionClose { handle });
+                }
+                PlatformRequest::SpawnProcess {
+                    tag,
+                    mut command,
+                    buf_len,
+                } => {
+                    let mut spawned = false;
+                    for (i, p) in processes.iter_mut().enumerate() {
+                        if p.is_some() {
+                            continue;
+                        }
 
-                            let handle = PlatformProcessHandle(i as _);
-                            if let Ok(child) = command.spawn() {
-                                let process = Process::new(child, tag, buf_len);
-                                if let Some(fd) = process.try_as_raw_fd() {
-                                    kqueue.add(Event::Fd(fd), PROCESSES_START_INDEX + i);
-                                }
-                                *p = Some(process);
-                                events.push(PlatformEvent::ProcessSpawned { tag, handle });
-                                spawned = true;
+                        let handle = PlatformProcessHandle(i as _);
+                        if let Ok(child) = command.spawn() {
+                            let process = Process::new(child, tag, buf_len);
+                            if let Some(fd) = process.try_as_raw_fd() {
+                                kqueue.add(Event::Fd(fd), PROCESSES_START_INDEX + i);
                             }
-                            break;
-                        }
-                        if !spawned {
-                            events.push(PlatformEvent::ProcessExit { tag });
+                            *p = Some(process);
+                            events.push(PlatformEvent::ProcessSpawned { tag, handle });
+                            spawned = true;
                         }
+                        break;
                     }
-                    PlatformRequest::WriteToProcess { handle, buf } => {
-                        let index = handle.0 as usize;
-                        if let Some(ref mut process) = processes[index] {
-                            if !process.write(buf.as_bytes()) {
-                                if let Some(fd) = process.try_as_raw_fd() {
-                                    kqueue.remove(Event::Fd(fd));
-                                }
-                                let tag = process.tag();
-                                process.kill();
-                                processes[index] = None;
-                                events.push(PlatformEvent::ProcessExit { tag });
-                            }
-                        }
-                        application.ctx.platform.buf_pool.release(buf);
+                    if !spawned {
+                        events.push(PlatformEvent::ProcessExit { tag });
                     }
-                    PlatformRequest::CloseProcessInput { handle } => {
-                        if let Some(ref mut process) = processes[handle.0 as usize] {
-                            process.close_input();
-                        }
-                    }
-                    PlatformRequest::KillProcess { handle } => {
-                        let index = handle.0 as usize;
-                        if let Some(ref mut process) = processes[index] {
+                }
+                PlatformRequest::WriteToProcess { handle, buf } => {
+                    let index = handle.0 as usize;
+                    if let Some(ref mut process) = processes[index] {
+                        if !process.write(buf.as_bytes()) {
                             if let Some(fd) = process.try_as_raw_fd() {
                                 kqueue.remove(Event::Fd(fd));
                             }
@@ -366,12 +350,30 @@ fn run_server(config: ApplicationConfig, listener: UnixListener) {
                             events.push(PlatformEvent::ProcessExit { tag });
                         }
                     }
+                    application.ctx.platform.buf_pool.release(buf);
+                }
+                PlatformRequest::CloseProcessInput { handle } => {
+                    if let Some(ref mut process) = processes[handle.0 as usize] {
+                        process.close_input();
+                    }
+                }
+                PlatformRequest::KillProcess { handle } => {
+                    let index = handle.0 as usize;
+                    if let Some(ref mut process) = processes[index] {
+                        if let Some(fd) = process.try_as_raw_fd() {
+                            kqueue.remove(Event::Fd(fd));
+                        }
+                        let tag = process.tag();
+                        process.kill();
+                        processes[index] = None;
+                        events.push(PlatformEvent::ProcessExit { tag });
+                    }
                 }
             }
+        }
 
-            if !events.is_empty() {
-                timeout = Some(Duration::ZERO);
-            }
+        if !events.is_empty() {
+            timeout = Some(Duration::ZERO);
         }
     }
 }
@@ -484,3 +486,4 @@ fn run_client(args: Args, mut connection: UnixStream) {
     drop(terminal);
     drop(application);
 }
+
